"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callFunctionAsyncImplementation = void 0;
const client_lambda_1 = require("@aws-sdk/client-lambda");
const aws_clients_1 = require("./aws-clients");
const callFunctionAsyncImplementation = async ({ functionName, payload, region, timeoutInTest, }) => {
    const stringifiedPayload = JSON.stringify(payload);
    if (stringifiedPayload.length > 256 * 1024) {
        throw new Error(`Payload is too big: ${stringifiedPayload.length} bytes. Maximum size is 256 KB. This should not happen, please report this to the Remotion team. Payload: ${stringifiedPayload}`);
    }
    const result = await (0, aws_clients_1.getLambdaClient)(region, timeoutInTest, null).send(new client_lambda_1.InvokeCommand({
        FunctionName: functionName,
        Payload: stringifiedPayload,
        InvocationType: 'Event',
    }));
    if (result.FunctionError) {
        throw new Error(`Lambda function returned error: ${result.FunctionError} ${result.LogResult}`);
    }
};
exports.callFunctionAsyncImplementation = callFunctionAsyncImplementation;
