"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isLikelyToHaveAwsProfile = void 0;
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
const get_env_variable_1 = require("./get-env-variable");
const homeDirCache = {};
const getHomeDirCacheKey = () => {
    // geteuid is only available on POSIX platforms (i.e. not Windows or Android).
    if (process && process.geteuid) {
        return `${process.geteuid()}`;
    }
    return 'DEFAULT';
};
const getHomeDir = () => {
    const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${path_1.sep}` } = process.env;
    if (HOME)
        return HOME;
    if (USERPROFILE)
        return USERPROFILE;
    if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
    const homeDirCacheKey = getHomeDirCacheKey();
    if (!homeDirCache[homeDirCacheKey])
        homeDirCache[homeDirCacheKey] = (0, os_1.homedir)();
    return homeDirCache[homeDirCacheKey];
};
const ENV_CREDENTIALS_PATH = 'AWS_SHARED_CREDENTIALS_FILE';
// Logic is inline to https://github.com/smithy-lang/smithy-typescript/blob/main/packages/shared-ini-file-loader/src/getCredentialsFilepath.ts#L7
const pathOfCredentialsFile = () => {
    return ((0, get_env_variable_1.getEnvVariable)(ENV_CREDENTIALS_PATH) ||
        (0, path_1.join)(getHomeDir(), '.aws', 'credentials'));
};
const isLikelyToHaveAwsProfile = () => {
    // Supabase uses Deno and does not support readFile
    // https://github.com/remotion-dev/remotion/issues/4844
    if (typeof Deno !== 'undefined') {
        return false;
    }
    const credentialsFile = pathOfCredentialsFile();
    try {
        const content = (0, fs_1.readFileSync)(credentialsFile, 'utf-8');
        return content.includes('[default]');
    }
    catch (_a) {
        return false;
    }
};
exports.isLikelyToHaveAwsProfile = isLikelyToHaveAwsProfile;
