"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderVideoOnLambda = exports.renderMediaOnLambda = exports.renderMediaOnLambdaOptionalToRequired = exports.internalRenderMediaOnLambdaRaw = void 0;
const serverless_client_1 = require("@remotion/serverless-client");
const aws_provider_1 = require("./aws-provider");
const get_aws_urls_1 = require("./get-aws-urls");
const make_lambda_payload_1 = require("./make-lambda-payload");
const internalRenderMediaOnLambdaRaw = async (input) => {
    var _a;
    const { functionName, region, rendererFunctionName } = input;
    try {
        const res = await aws_provider_1.awsImplementation.callFunctionSync({
            functionName,
            type: serverless_client_1.ServerlessRoutines.start,
            payload: await (0, make_lambda_payload_1.makeLambdaRenderMediaPayload)(input),
            region,
            timeoutInTest: 120000,
            requestHandler: input.requestHandler,
        });
        return {
            renderId: res.renderId,
            bucketName: res.bucketName,
            cloudWatchLogs: (0, get_aws_urls_1.getCloudwatchRendererUrl)({
                functionName,
                region,
                renderId: res.renderId,
                rendererFunctionName: rendererFunctionName !== null && rendererFunctionName !== void 0 ? rendererFunctionName : null,
                chunk: null,
            }),
            cloudWatchMainLogs: (0, get_aws_urls_1.getCloudwatchMethodUrl)({
                renderId: res.renderId,
                functionName,
                method: serverless_client_1.ServerlessRoutines.launch,
                region,
                rendererFunctionName: rendererFunctionName !== null && rendererFunctionName !== void 0 ? rendererFunctionName : null,
            }),
            folderInS3Console: (0, get_aws_urls_1.getS3RenderUrl)({
                bucketName: res.bucketName,
                renderId: res.renderId,
                region,
            }),
            lambdaInsightsLogs: (0, get_aws_urls_1.getLambdaInsightsUrl)({
                functionName,
                region,
            }),
            progressJsonInConsole: (0, get_aws_urls_1.getProgressJsonUrl)({
                bucketName: res.bucketName,
                renderId: res.renderId,
                region,
            }),
        };
    }
    catch (err) {
        if ((_a = err.stack) === null || _a === void 0 ? void 0 : _a.includes('UnrecognizedClientException')) {
            throw new Error('UnrecognizedClientException: The AWS credentials provided were probably mixed up. Learn how to fix this issue here: https://remotion.dev/docs/lambda/troubleshooting/unrecognizedclientexception');
        }
        throw err;
    }
};
exports.internalRenderMediaOnLambdaRaw = internalRenderMediaOnLambdaRaw;
const renderMediaOnLambdaOptionalToRequired = (options) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17;
    return {
        offthreadVideoThreads: (_a = options.offthreadVideoThreads) !== null && _a !== void 0 ? _a : null,
        audioBitrate: (_b = options.audioBitrate) !== null && _b !== void 0 ? _b : null,
        audioCodec: (_c = options.audioCodec) !== null && _c !== void 0 ? _c : null,
        chromiumOptions: (_d = options.chromiumOptions) !== null && _d !== void 0 ? _d : {},
        codec: options.codec,
        colorSpace: (_e = options.colorSpace) !== null && _e !== void 0 ? _e : null,
        composition: options.composition,
        concurrencyPerLambda: (_f = options.concurrencyPerLambda) !== null && _f !== void 0 ? _f : 1,
        crf: options.crf,
        downloadBehavior: (_g = options.downloadBehavior) !== null && _g !== void 0 ? _g : { type: 'play-in-browser' },
        envVariables: (_h = options.envVariables) !== null && _h !== void 0 ? _h : {},
        everyNthFrame: (_j = options.everyNthFrame) !== null && _j !== void 0 ? _j : 1,
        forceBucketName: (_k = options.forceBucketName) !== null && _k !== void 0 ? _k : null,
        forceHeight: (_l = options.forceHeight) !== null && _l !== void 0 ? _l : null,
        forceWidth: (_m = options.forceWidth) !== null && _m !== void 0 ? _m : null,
        frameRange: (_o = options.frameRange) !== null && _o !== void 0 ? _o : null,
        framesPerLambda: (_p = options.framesPerLambda) !== null && _p !== void 0 ? _p : null,
        functionName: options.functionName,
        imageFormat: (_q = options.imageFormat) !== null && _q !== void 0 ? _q : 'jpeg',
        inputProps: (_r = options.inputProps) !== null && _r !== void 0 ? _r : {},
        jpegQuality: (_s = options.jpegQuality) !== null && _s !== void 0 ? _s : 80,
        logLevel: (_t = options.logLevel) !== null && _t !== void 0 ? _t : 'info',
        maxRetries: (_u = options.maxRetries) !== null && _u !== void 0 ? _u : 1,
        muted: (_v = options.muted) !== null && _v !== void 0 ? _v : false,
        numberOfGifLoops: (_w = options.numberOfGifLoops) !== null && _w !== void 0 ? _w : null,
        offthreadVideoCacheSizeInBytes: (_x = options.offthreadVideoCacheSizeInBytes) !== null && _x !== void 0 ? _x : null,
        outName: (_y = options.outName) !== null && _y !== void 0 ? _y : null,
        overwrite: (_z = options.overwrite) !== null && _z !== void 0 ? _z : false,
        pixelFormat: (_0 = options.pixelFormat) !== null && _0 !== void 0 ? _0 : undefined,
        privacy: (_1 = options.privacy) !== null && _1 !== void 0 ? _1 : 'public',
        proResProfile: (_2 = options.proResProfile) !== null && _2 !== void 0 ? _2 : undefined,
        region: options.region,
        rendererFunctionName: (_3 = options.rendererFunctionName) !== null && _3 !== void 0 ? _3 : null,
        scale: (_4 = options.scale) !== null && _4 !== void 0 ? _4 : 1,
        serveUrl: options.serveUrl,
        timeoutInMilliseconds: (_5 = options.timeoutInMilliseconds) !== null && _5 !== void 0 ? _5 : 30000,
        videoBitrate: (_6 = options.videoBitrate) !== null && _6 !== void 0 ? _6 : null,
        encodingMaxRate: (_7 = options.encodingMaxRate) !== null && _7 !== void 0 ? _7 : null,
        encodingBufferSize: (_8 = options.encodingBufferSize) !== null && _8 !== void 0 ? _8 : null,
        webhook: (_9 = options.webhook) !== null && _9 !== void 0 ? _9 : null,
        x264Preset: (_10 = options.x264Preset) !== null && _10 !== void 0 ? _10 : null,
        deleteAfter: (_11 = options.deleteAfter) !== null && _11 !== void 0 ? _11 : null,
        preferLossless: (_12 = options.preferLossless) !== null && _12 !== void 0 ? _12 : false,
        forcePathStyle: (_13 = options.forcePathStyle) !== null && _13 !== void 0 ? _13 : false,
        indent: false,
        metadata: (_14 = options.metadata) !== null && _14 !== void 0 ? _14 : null,
        apiKey: (_15 = options.apiKey) !== null && _15 !== void 0 ? _15 : null,
        storageClass: (_16 = options.storageClass) !== null && _16 !== void 0 ? _16 : null,
        requestHandler: (_17 = options.requestHandler) !== null && _17 !== void 0 ? _17 : null,
    };
};
exports.renderMediaOnLambdaOptionalToRequired = renderMediaOnLambdaOptionalToRequired;
const wrapped = (0, serverless_client_1.wrapWithErrorHandling)(exports.internalRenderMediaOnLambdaRaw);
/*
 * @description Kicks off a render process on Remotion Lambda. The progress can be tracked using getRenderProgress().
 * @see [Documentation](https://remotion.dev/docs/lambda/rendermediaonlambda)
 */
const renderMediaOnLambda = (options) => {
    if (options.quality) {
        throw new Error('quality has been renamed to jpegQuality. Please rename the option.');
    }
    return wrapped((0, exports.renderMediaOnLambdaOptionalToRequired)(options));
};
exports.renderMediaOnLambda = renderMediaOnLambda;
/**
 * @deprecated Renamed to renderMediaOnLambda()
 */
exports.renderVideoOnLambda = exports.renderMediaOnLambda;
